@@ -10,7 +10,7 @@ use Exporter qw( import );
 
 our @EXPORT = qw( xy2d d2xy );
 
-our $VERSION = 1.001;
+our $VERSION = 1.002;
 
 # optional constructor if you want OO-style
 sub new {
@@ -69,11 +69,8 @@ sub _rot {
 sub _valid_n {
     my ($n) = @_;
     $n = $n->{ n } if ref $n;
-    {
-        no integer;
-        2 ** int(log($n) / log(2)) == $n or confess("Side-length $n is not a power of 2");
-    }
-    return $n;
+    ($n & ($n - 1)) or return $n;
+    confess("Side-length $n is not a power of 2");
 }
 
 1;
